﻿using System.Collections.Generic;
using System;
using System.IO;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace JSViewer_MVC.Controllers
{
    public class HomeController : Controller
    {
        [HttpGet]
        [Route("")]
        [Route("index")]
        public ActionResult Index()
        {
            return Resource("index.html");
        }

        [HttpGet]
        [Route("{file}")]
        public ActionResult Resource(string file)
        {
            string filePath = Path.Combine(HttpRuntime.AppDomainAppPath, "wwwroot", file);
            if (!System.IO.File.Exists(filePath))
                return new HttpNotFoundResult();

            if (Path.GetExtension(file) == ".html")
                return new ContentResult() { Content = System.IO.File.ReadAllText(filePath), ContentType = "text/html" };

            var resFile = System.IO.File.ReadAllBytes(filePath);

            if (Path.GetExtension(file) == ".ico")
                return new FileContentResult(resFile, "image/x-icon") { FileDownloadName = file };

            return new FileContentResult(resFile, GetMimeType(file)) { FileDownloadName = file };
        }

        [HttpGet]
        [Route("reports")]
        public ActionResult Reports()
        {
            string[] validExtensions = { ".rdl", ".rdlx", ".rdlx-master", ".rpx" };
            var reportsList = GetFileStoreReports(validExtensions);
            return new JsonResult
            {
                Data = reportsList,
                JsonRequestBehavior = JsonRequestBehavior.AllowGet
            };
        }

        [HttpGet]
        [Route("data")]
        public JsonResult GetLists()
        {
            List<Customer> customers = new List<Customer>
            {
                new Customer(){first_name= "Customer1", city = "City1", currency = "$", date = DateTime.Now, id = 1},
                new Customer(){first_name= "Customer2", city = "City2", currency = "$", date = DateTime.Now, id = 2},
                new Customer(){first_name= "Customer3", city = "City3", currency = "$", date = DateTime.Now, id = 3},
                new Customer(){first_name= "Customer4", city = "City4", currency = "$", date = DateTime.Now, id = 4},
                new Customer(){first_name= "Customer5", city = "City5", currency = "$", date = DateTime.Now, id = 5}
            };

            return Json(customers, JsonRequestBehavior.AllowGet);
        }

        /// <summary>
        /// Gets the MIME type from the file extension
        /// </summary>
        /// <param name="fileName">File name</param>
        /// <returns>MIME type</returns>
        private static string GetMimeType(string fileName)
        {
            if (fileName.EndsWith(".css"))
                return "text/css";

            if (fileName.EndsWith(".js"))
                return "text/javascript";

            return "text/html";
        }

        /// <summary>
        /// Gets report names from folder
        /// </summary>
        /// <returns>Report names</returns>
        private string[] GetFileStoreReports(string[] validExtensions)
        {
            return Startup.ReportsDirectory
                .EnumerateFiles("*.*")
                .Select(x => x.Name)
                .Where(x => validExtensions.Any(x.EndsWith))
                .ToArray();
        }
    }
    public class Customer
    {
        public int id { get; set; }
        public string first_name { get; set; }
        public string gender { get; set; }
        public string language { get; set; }
        public string city { get; set; }
        public string specialcharacter { get; set; }
        public string links { get; set; }
        public string currency { get; set; }
        public string huge_content { get; set; }
        public DateTime date { get; set; }
    }
}